@@ -221,10 +221,7 @@ class AnalysisSTEAM:
             file_model_data = os.path.join(self.library_path, step.case_model + 's', step.file_model_data, 'input', 'modelData_' + step.file_model_data + '.yaml')
         else:
             file_model_data = os.path.join(self.library_path,'modelData_' + step.file_model_data + '.yaml')
-        if 'FiQuS' in step.software:
-            local_model_folder = os.path.join(Path(self.settings.local_FiQuS_folder), step.simulation_name, str(step.simulation_number))
-        else:
-            local_model_folder = None
+
         case_model      = step.case_model
         software        = step.software  # remember this is a list, not a string
         verbose_of_step = step.verbose
@@ -239,7 +236,7 @@ class AnalysisSTEAM:
         BM = BuilderModel(file_model_data=file_model_data, case_model=case_model, software=software,
                           verbose=verbose_of_step, flag_build=flag_build, flag_dump_all=flag_dump_all,
                           flag_plot_all=flag_plot_all, flag_json=flag_json, output_path=output_folder,
-                          relative_path_settings=relative_path_settings, local_model_path=local_model_folder)
+                          relative_path_settings=relative_path_settings)
 
         # Build simulation file
         if step.simulation_number:
@@ -314,7 +311,7 @@ class AnalysisSTEAM:
             if len_simulation_numbers > 0:
                 simulation_number = step.simulation_numbers[v]
                 if 'FiQuS' in step.software:
-                    BM.buildFiQuS(local_folder=os.path.join(Path(self.settings.local_FiQuS_folder), step.simulation_name, str(simulation_number)))
+                    BM.buildFiQuS()
                     self.setup_sim_FiQuS(simulation_name=step.simulation_name, simulation_type=step.type, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_json = BM.flag_json
