@@ -11,7 +11,7 @@ from steam_sdk.data.DataModelMagnet import MeshMultipole
 from steam_sdk.data.DataModelMagnet import PostProcMultipole
 
 
-class RibbonFiQuS(BaseModel):
+class MultipoleRibbon(BaseModel):
     """
         Rutherford cable type
     """
@@ -20,7 +20,7 @@ class RibbonFiQuS(BaseModel):
     bare_cable_height_mean: float = None
 
 
-class RutherfordFiQuS(BaseModel):
+class MultipoleRutherford(BaseModel):
     """
         Rutherford cable type
     """
@@ -29,36 +29,36 @@ class RutherfordFiQuS(BaseModel):
     bare_cable_height_mean: float = None
 
 
-class ConductorFiQuS(BaseModel):
+class MultipoleConductor(BaseModel):
     """
         Class for conductor type
     """
-    cable: Union[RutherfordFiQuS, RibbonFiQuS] = {'type': 'Rutherford'}
+    cable: Union[MultipoleRutherford, MultipoleRibbon] = {'type': 'Rutherford'}
 
 
-class GeneralSetting(BaseModel):
+class MultipoleGeneralSetting(BaseModel):
     """
         Class for general information on the case study
     """
     I_ref: List[float] = None
 
 
-class ModelDataSetting(BaseModel):
+class MultipoleModelDataSetting(BaseModel):
     """
         Class for model data
     """
-    general_parameters: GeneralSetting = GeneralSetting()
-    conductors: Dict[str, ConductorFiQuS] = {}
+    general_parameters: MultipoleGeneralSetting = MultipoleGeneralSetting()
+    conductors: Dict[str, MultipoleConductor] = {}
 
 
-class FiQuSSettings(BaseModel):
+class MultipoleSettings(BaseModel):
     """
         Class for FiQuS multipole settings (.set)
     """
-    Model_Data_GS: ModelDataSetting = ModelDataSetting()
+    Model_Data_GS: MultipoleModelDataSetting = MultipoleModelDataSetting()
 
 
-class FiQuSGeometry(BaseModel):
+class MultipoleGeometry(BaseModel):
     """
         Class for FiQuS multipole Roxie data (.geom)
     """
@@ -66,14 +66,16 @@ class FiQuSGeometry(BaseModel):
 
 
 # Modified classes with respect to Options_FiQuS.multipole
-class SolveMultipoleFiQuS(BaseModel):
+class MultipoleSolve(BaseModel):
     I_initial: List[float] = None
     pro_template: str = None  # file name of .pro template file
+    getdp_exe_path: str = None  # absolute path to GetDP executable
+    BH_curves_path: str = None  # absolute path to iron BH curves pro file
 ############################
 
 
 # Modified classes with respect to Options_FiQuS.cct
-class Winding_gFiQuS(BaseModel):  # Geometry related windings _inputs
+class CCTWinding_G(BaseModel):  # Geometry related windings _inputs
     """
         Level 2: Class for FiQuS CCT
     """
@@ -89,7 +91,7 @@ class Winding_gFiQuS(BaseModel):  # Geometry related windings _inputs
     wwhs: List[float] = None  # winding wire heights (assuming rectangular)
 
 
-class Former_gFiQuS(BaseModel):  # Geometry related formers _inputs
+class CCTFormerG(BaseModel):  # Geometry related formers _inputs
     """
         Level 2: Class for FiQuS CCT
     """
@@ -100,17 +102,17 @@ class Former_gFiQuS(BaseModel):  # Geometry related formers _inputs
     z_maxs: List[float] = None  # extend of former in positive z direction
 
 
-class GeometryCCTFiQuS(BaseModel):
+class CCTGeometry(BaseModel):
     """
         Level 2: Class for FiQuS CCT for FiQuS input
     """
-    windings: Winding_gFiQuS = Winding_gFiQuS()
+    windings: CCTWinding_G = CCTWinding_G()
     fqpls: FQPL_g = FQPL_g()
-    formers: Former_gFiQuS = Former_gFiQuS()
+    formers: CCTFormerG = CCTFormerG()
     air: Air_g = Air_g()
 
 
-class PostprocCCTFiQuS(BaseModel):
+class CCTPostproc(BaseModel):
     """
         Class for FiQuS CCT input file
     """
@@ -130,10 +132,10 @@ class CCTDM(BaseModel):
         Class for FiQuS CCT
     """
     type: Literal['CCT']
-    geometry: GeometryCCTFiQuS = GeometryCCTFiQuS()
+    geometry: CCTGeometry = CCTGeometry()
     mesh: MeshCCT = MeshCCT()
     solve: SolveCCT = SolveCCT()
-    postproc: PostprocCCTFiQuS = PostprocCCTFiQuS()
+    postproc: CCTPostproc = CCTPostproc()
 
 
 class MPDM(BaseModel):
@@ -143,11 +145,11 @@ class MPDM(BaseModel):
     type: Literal['multipole']
     options: OptionMultipole = OptionMultipole()
     mesh: MeshMultipole = MeshMultipole()
-    solve: SolveMultipoleFiQuS = SolveMultipoleFiQuS()
+    solve: MultipoleSolve = MultipoleSolve()
     post_proc: PostProcMultipole = PostProcMultipole()
 
 
-class GeneralFiQuS(BaseModel):
+class General(BaseModel):
     """
         Class for FiQuS general
     """
@@ -158,7 +160,7 @@ class DataFiQuS(BaseModel):
     """
         Class for FiQuS
     """
-    general: GeneralFiQuS = GeneralFiQuS()
+    general: General = General()
     run: RunFiQuS = RunFiQuS()
     magnet: Union[MPDM, CCTDM] = {'type': 'multipole'}
 
