@@ -1,8 +1,7 @@
-from dataclasses import dataclass
+from pydantic import BaseModel
 
 
-@dataclass
-class DataSettingsSTEAM:
+class DataSettingsSTEAM(BaseModel):
     """
         Dataclass of settings for STEAM analyses
         This will be populated either form a local settings file (if flag_permanent_settings=False)
@@ -16,9 +15,11 @@ class DataSettingsSTEAM:
     ProteCCT_path:       str = None  #
     PSPICE_path:         str = None  #
     COSIM_path:          str = None  #
+    FiQuS_GetDP_path:    str = None  # full path to CERN GetDP build executable
     FiQuS_path:          str = None  #
-    DAKOTA_path:         str = None  #
+    Dakota_path:         str = None  #
     PSPICE_library_path: str = None  #
+    local_Dakota_path:  str = None  # full path to local Dakota folder
     local_FiQuS_folder:  str = None  # full path to local FiQuS folder
     local_LEDET_folder:  str = None  # full path to local LEDET folder
     local_PyBBQ_folder:  str = None  # full path to local PyBBQ folder
