@@ -3,7 +3,7 @@ from pathlib import Path
 import yaml
 
 from steam_sdk.data.DataModelConductor import DataModelConductor
-from steam_sdk.parsers.dict_to_yaml import dict_to_yaml
+from steam_sdk.parsers.ParserYAML import dict_to_yaml
 
 if __name__ == "__main__":
     path_models = Path.joinpath(Path(__file__).parent.parent.parent, 'C:\\Users\emm\cernbox\SWAN_projects\steam_models\conductors')
